@@ -119,10 +119,8 @@ static void applet_change_orient(MatePanelApplet* applet, MatePanelAppletOrient
 		return;
 
 	tasklist->orientation = new_orient;
-
-#if WNCK_CHECK_VERSION (3, 4, 6)
 	wnck_tasklist_set_orientation (WNCK_TASKLIST (tasklist->tasklist), new_orient);
-#endif
+
 	tasklist_update(tasklist);
 }
 
@@ -166,7 +164,7 @@ static const GtkActionEntry tasklist_menu_actions[] = {
 	},
 	{
 		"TasklistPreferences",
-		GTK_STOCK_PROPERTIES,
+		"document-properties",
 		N_("_Preferences"),
 		NULL,
 		NULL,
@@ -174,7 +172,7 @@ static const GtkActionEntry tasklist_menu_actions[] = {
 	},
 	{
 		"TasklistHelp",
-		GTK_STOCK_HELP,
+		"help-browser",
 		N_("_Help"),
 		NULL,
 		NULL,
@@ -182,7 +180,7 @@ static const GtkActionEntry tasklist_menu_actions[] = {
 	},
 	{
 		"TasklistAbout",
-		GTK_STOCK_ABOUT,
+		"help-about",
 		N_("_About"),
 		NULL,
 		NULL,
@@ -375,14 +373,13 @@ gboolean window_list_applet_fill(MatePanelApplet* applet)
 	TasklistData* tasklist;
 	GtkActionGroup* action_group;
 	gchar* ui_path;
-#if GTK_CHECK_VERSION (3, 20, 0)
 	GtkCssProvider  *provider;
 	GdkScreen *screen;
-#endif
+
 	tasklist = g_new0(TasklistData, 1);
 
 	tasklist->applet = GTK_WIDGET(applet);
-#if GTK_CHECK_VERSION (3, 20, 0)
+
 	provider = gtk_css_provider_new ();
 	screen = gdk_screen_get_default ();
 	gtk_css_provider_load_from_data (provider,
@@ -395,7 +392,7 @@ gboolean window_list_applet_fill(MatePanelApplet* applet)
 										GTK_STYLE_PROVIDER (provider),
 										GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 	g_object_unref (provider);
-#endif
+
 	mate_panel_applet_set_flags(MATE_PANEL_APPLET(tasklist->applet), MATE_PANEL_APPLET_EXPAND_MAJOR | MATE_PANEL_APPLET_EXPAND_MINOR | MATE_PANEL_APPLET_HAS_HANDLE);
 
 	setup_gsettings(tasklist);
@@ -423,11 +420,8 @@ gboolean window_list_applet_fill(MatePanelApplet* applet)
 
 	tasklist->tasklist = wnck_tasklist_new();
 
-#if WNCK_CHECK_VERSION (3, 4, 6)
 	wnck_tasklist_set_orientation (WNCK_TASKLIST (tasklist->tasklist), tasklist->orientation);
 	wnck_tasklist_set_middle_click_close (WNCK_TASKLIST (tasklist->tasklist), TRUE);
-#endif
-
 	wnck_tasklist_set_icon_loader(WNCK_TASKLIST(tasklist->tasklist), icon_loader_func, tasklist, NULL);
 
 	g_signal_connect(G_OBJECT(tasklist->tasklist), "destroy", G_CALLBACK(destroy_tasklist), tasklist);
@@ -538,7 +532,7 @@ static void display_about_dialog(GtkAction* action, TasklistData* tasklist)
 	};
 
 	char copyright[] = \
-		"Copyright \xc2\xa9 2012-2017 MATE developers\n"
+		"Copyright \xc2\xa9 2012-2018 MATE developers\n"
 		"Copyright \xc2\xa9 2011 Perberos\n"
 		"Copyright \xc2\xa9 2002 Red Hat, Inc.";
 
@@ -688,22 +682,9 @@ static void display_properties_dialog(GtkAction* action, TasklistData* tasklist)
 
 static void destroy_tasklist(GtkWidget* widget, TasklistData* tasklist)
 {
+	g_signal_handlers_disconnect_by_data (G_OBJECT (tasklist->applet), tasklist);
 
-	g_signal_handlers_disconnect_by_func(G_OBJECT(tasklist->applet),
-						G_CALLBACK(applet_change_orient), tasklist);
-	g_signal_handlers_disconnect_by_func(G_OBJECT(tasklist->applet),
-						G_CALLBACK(applet_change_pixel_size), tasklist);
-	g_signal_handlers_disconnect_by_func(G_OBJECT(tasklist->applet),
-						G_CALLBACK(applet_change_background), tasklist);
-	g_signal_handlers_disconnect_by_func (tasklist->settings,
-					  G_CALLBACK (display_all_workspaces_changed),
-					  tasklist);
-	g_signal_handlers_disconnect_by_func (tasklist->settings,
-					  G_CALLBACK (group_windows_changed),
-					  tasklist);
-	g_signal_handlers_disconnect_by_func (tasklist->settings,
-					  G_CALLBACK (move_unminimized_windows_changed),
-					  tasklist);
+	g_signal_handlers_disconnect_by_data (tasklist->settings, tasklist);
 
 	g_object_unref(tasklist->settings);
 
