@@ -323,7 +323,7 @@ static gboolean applet_scroll(MatePanelApplet* applet, GdkEventScroll* event, Pa
 static const GtkActionEntry pager_menu_actions[] = {
 	{
 		"PagerPreferences",
-		GTK_STOCK_PROPERTIES,
+		"document-properties",
 		N_("_Preferences"),
 		NULL,
 		NULL,
@@ -331,7 +331,7 @@ static const GtkActionEntry pager_menu_actions[] = {
 	},
 	{
 		"PagerHelp",
-		GTK_STOCK_HELP,
+		"help-browser",
 		N_("_Help"),
 		NULL,
 		NULL,
@@ -339,7 +339,7 @@ static const GtkActionEntry pager_menu_actions[] = {
 	},
 	{
 		"PagerAbout",
-		GTK_STOCK_ABOUT,
+		"help-about",
 		N_("_About"),
 		NULL,
 		NULL,
@@ -580,7 +580,7 @@ static void display_about_dialog(GtkAction* action, PagerData* pager)
 	};
 
 	char copyright[] = \
-		"Copyright \xc2\xa9 2012-2017 MATE developers\n"
+		"Copyright \xc2\xa9 2012-2018 MATE developers\n"
 		"Copyright \xc2\xa9 2011 Perberos\n"
 		"Copyright \xc2\xa9 2002 Red Hat, Inc.";
 
@@ -961,18 +961,8 @@ static void display_properties_dialog(GtkAction* action, PagerData* pager)
 
 static void destroy_pager(GtkWidget* widget, PagerData* pager)
 {
-	g_signal_handlers_disconnect_by_func (pager->settings,
-					  G_CALLBACK (num_rows_changed),
-					  pager);
-	g_signal_handlers_disconnect_by_func (pager->settings,
-					  G_CALLBACK (display_workspace_names_changed),
-					  pager);
-	g_signal_handlers_disconnect_by_func (pager->settings,
-					  G_CALLBACK (all_workspaces_changed),
-					  pager);
-	g_signal_handlers_disconnect_by_func (pager->settings,
-					  G_CALLBACK (wrap_workspaces_changed),
-					  pager);
+	g_signal_handlers_disconnect_by_data (pager->settings, pager);
+
 	g_object_unref (pager->settings);
 
 	if (pager->properties_dialog)
