@@ -46,9 +46,8 @@
 #include "mate-panel-applet-factory.h"
 #include "mate-panel-applet-marshal.h"
 #include "mate-panel-applet-enums.h"
-#if GTK_CHECK_VERSION (3, 18, 0)
 #include "panel-plug-private.h"
-#endif
+
 #define MATE_PANEL_APPLET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_APPLET, MatePanelAppletPrivate))
 
 struct _MatePanelAppletPrivate {
@@ -72,9 +71,6 @@ struct _MatePanelAppletPrivate {
 	MatePanelAppletOrient  orient;
 	guint              size;
 	char              *background;
-#if !GTK_CHECK_VERSION (3, 18, 0)
-	GtkWidget         *background_widget;
-#endif
 
 	int                previous_width;
 	int                previous_height;
@@ -140,7 +136,7 @@ static const gchar panel_menu_ui[] =
 	"</ui>\n";
 
 static const GtkActionEntry menu_entries[] = {
-	{ "Remove", GTK_STOCK_REMOVE, N_("_Remove From Panel"),
+	{ "Remove", "list-remove", N_("_Remove From Panel"),
 	  NULL, NULL,
 	  G_CALLBACK (mate_panel_applet_menu_cmd_remove) },
 	{ "Move", NULL, N_("_Move"),
@@ -273,6 +269,13 @@ mate_panel_applet_size_hints_changed (MatePanelApplet *applet,
 	return FALSE;
 }
 
+/**
+ * mate_panel_applet_set_size_hints: 
+ * @applet: applet
+ * @size_hints: (array length=n_elements): List of integers
+ * @n_elements: Length of @size_hints
+ * @base_size: base_size
+ */
 void
 mate_panel_applet_set_size_hints (MatePanelApplet *applet,
 			     const int   *size_hints,
@@ -796,8 +799,6 @@ mate_panel_applet_position_menu (GtkMenu   *menu,
 	int             menu_y = 0;
 	int             pointer_x;
 	int             pointer_y;
-	int             screen_width;
-	int             screen_height;
 
 	g_return_if_fail (PANEL_IS_APPLET (widget));
 
@@ -809,21 +810,15 @@ mate_panel_applet_position_menu (GtkMenu   *menu,
 	gtk_widget_get_preferred_size (GTK_WIDGET (menu), &requisition, NULL);
 	gdk_window_get_origin (gtk_widget_get_window (widget),
 			       &menu_x, &menu_y);
-#if GTK_CHECK_VERSION (3, 20, 0)
+
 	device = gdk_seat_get_pointer (gdk_display_get_default_seat (gtk_widget_get_display (widget)));
 	gdk_window_get_device_position (gtk_widget_get_window (widget), device, &pointer_x, &pointer_y, NULL);
-#else
-	device = gdk_device_manager_get_client_pointer (gdk_display_get_device_manager (gtk_widget_get_display (widget)));
-	gdk_window_get_device_position (gtk_widget_get_window (widget), device, &pointer_x, &pointer_y, NULL);
-#endif
+
 	gtk_widget_get_allocation (widget, &allocation);
 
 	menu_x += allocation.x;
 	menu_y += allocation.y;
 
-	gdk_window_get_geometry (gdk_screen_get_root_window (screen), NULL, NULL,
-				 &screen_width, &screen_height);
-
 	if (applet->priv->orient == MATE_PANEL_APPLET_ORIENT_UP ||
 	    applet->priv->orient == MATE_PANEL_APPLET_ORIENT_DOWN) {
 		if (gtk_widget_get_direction (GTK_WIDGET (menu)) != GTK_TEXT_DIR_RTL) {
@@ -839,9 +834,9 @@ mate_panel_applet_position_menu (GtkMenu   *menu,
 					       allocation.width - requisition.width);
 			}
 		}
-		menu_x = MIN (menu_x, screen_width - requisition.width);
+		menu_x = MIN (menu_x, WidthOfScreen (gdk_x11_screen_get_xscreen (screen)) - requisition.width);
 
-		if (menu_y > screen_height / 2)
+		if (menu_y > HeightOfScreen (gdk_x11_screen_get_xscreen (screen)) / 2)
 			menu_y -= requisition.height;
 		else
 			menu_y += allocation.height;
@@ -849,9 +844,9 @@ mate_panel_applet_position_menu (GtkMenu   *menu,
 		if (pointer_y < allocation.height &&
 		    requisition.height < pointer_y)
 			menu_y += MIN (pointer_y, allocation.height - requisition.height);
-		menu_y = MIN (menu_y, screen_height - requisition.height);
+		menu_y = MIN (menu_y, HeightOfScreen (gdk_x11_screen_get_xscreen (screen)) - requisition.height);
 
-		if (menu_x > screen_width / 2)
+		if (menu_x > WidthOfScreen (gdk_x11_screen_get_xscreen (screen)) / 2)
 			menu_x -= requisition.width;
 		else
 			menu_x += allocation.width;
@@ -929,7 +924,6 @@ mate_panel_applet_button_event (MatePanelApplet      *applet,
 	socket_window = gtk_plug_get_socket_window (GTK_PLUG (widget));
 
 	if (event->type == GDK_BUTTON_PRESS) {
-#if GTK_CHECK_VERSION (3, 20, 0)
 		GdkDisplay *display;
 		GdkSeat *seat;
 
@@ -944,16 +938,6 @@ mate_panel_applet_button_event (MatePanelApplet      *applet,
 		 * We don't want to hog the pointer on our parent.
 		 */
 		gdk_seat_ungrab (seat);
-#else
-		xevent.xbutton.type = ButtonPress;
-
-		/* X does an automatic pointer grab on button press
-		 * if we have both button press and release events
-		 * selected.
-		 * We don't want to hog the pointer on our parent.
-		 */
-		gdk_device_ungrab (event->device, GDK_CURRENT_TIME);
-#endif
 	} else {
 		xevent.xbutton.type = ButtonRelease;
 	}
@@ -1025,29 +1009,28 @@ mate_panel_applet_popup_menu (GtkWidget *widget)
 	return TRUE;
 }
 
-#if !GTK_CHECK_VERSION (3, 18, 0)
 static void
 mate_panel_applet_get_preferred_width (GtkWidget *widget,
 				       int       *minimum_width,
 				       int       *natural_width)
 {
-	int focus_width = 0;
+	MatePanelApplet *applet = MATE_PANEL_APPLET (widget);
+	gint scale;
 
 	GTK_WIDGET_CLASS (mate_panel_applet_parent_class)->get_preferred_width (widget,
 										minimum_width,
 										natural_width);
-	if (!mate_panel_applet_can_focus (widget))
-		return;
 
-	/* We are deliberately ignoring focus-padding here to
-	 * save valuable panel real estate.
-	 */
-	gtk_widget_style_get (widget,
-			      "focus-line-width", &focus_width,
-			      NULL);
-
-	*minimum_width += 2 * focus_width;
-	*natural_width += 2 * focus_width;
+	if (applet->priv->out_of_process) {
+		/* Out-of-process applets end up scaled up doubly. We divide by the scale factor to ensure
+		 * they are back at their own intended size.
+		 */
+		scale = gtk_widget_get_scale_factor (widget);
+		if (scale) {
+			*minimum_width /= scale;
+			*natural_width /= scale;
+		}
+	}
 }
 
 static void
@@ -1055,25 +1038,24 @@ mate_panel_applet_get_preferred_height (GtkWidget *widget,
 					int       *minimum_height,
 					int       *natural_height)
 {
-	int focus_width = 0;
+	MatePanelApplet *applet = MATE_PANEL_APPLET (widget);
+	gint scale;
 
 	GTK_WIDGET_CLASS (mate_panel_applet_parent_class)->get_preferred_height (widget,
-										 minimum_height,
-										 natural_height);
-	if (!mate_panel_applet_can_focus (widget))
-		return;
+										minimum_height,
+										natural_height);
 
-	/* We are deliberately ignoring focus-padding here to
-	 * save valuable panel real estate.
-	 */
-	gtk_widget_style_get (widget,
-			      "focus-line-width", &focus_width,
-			      NULL);
-
-	*minimum_height += 2 * focus_width;
-	*natural_height += 2 * focus_width;
+	if (applet->priv->out_of_process) {
+		/* Out-of-process applets end up scaled up doubly. We divide by the scale factor to ensure
+		 * they are back at their own intended size.
+		 */
+		scale = gtk_widget_get_scale_factor (widget);
+		if (scale) {
+			*minimum_height /= scale;
+			*natural_height /= scale;
+		}
+	}
 }
-#endif
 
 static GtkSizeRequestMode
 mate_panel_applet_get_request_mode (GtkWidget *widget)
@@ -1097,36 +1079,19 @@ mate_panel_applet_size_allocate (GtkWidget     *widget,
 	GtkBin        *bin;
 	GtkWidget     *child;
 	int            border_width;
-#if !GTK_CHECK_VERSION (3, 18, 0)
-	int            focus_width = 0;
-#endif
 	MatePanelApplet   *applet;
 
 	if (!mate_panel_applet_can_focus (widget)) {
 		GTK_WIDGET_CLASS (mate_panel_applet_parent_class)->size_allocate (widget, allocation);
 	} else {
-#if !GTK_CHECK_VERSION (3, 18, 0)
-		/*
-		 * We are deliberately ignoring focus-padding here to
-		 * save valuable panel real estate.
-		 */
-		gtk_widget_style_get (widget,
-				      "focus-line-width", &focus_width,
-				      NULL);
-#endif
 
 		border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
 
 		gtk_widget_set_allocation (widget, allocation);
 		bin = GTK_BIN (widget);
 
-#if GTK_CHECK_VERSION (3, 18, 0)
 		child_allocation.x = 0;
 		child_allocation.y = 0;
-#else
-		child_allocation.x = focus_width;
-		child_allocation.y = focus_width;
-#endif
 
 		child_allocation.width  = MAX (allocation->width  - border_width * 2, 0);
 		child_allocation.height = MAX (allocation->height - border_width * 2, 0);
@@ -1138,11 +1103,6 @@ mate_panel_applet_size_allocate (GtkWidget     *widget,
 						child_allocation.width,
 						child_allocation.height);
 
-#if !GTK_CHECK_VERSION (3, 18, 0)
-		child_allocation.width  = MAX (child_allocation.width  - 2 * focus_width, 0);
-		child_allocation.height = MAX (child_allocation.height - 2 * focus_width, 0);
-#endif
-
 		child = gtk_bin_get_child (bin);
 		if (child)
 			gtk_widget_size_allocate (child, &child_allocation);
@@ -1163,9 +1123,6 @@ static gboolean mate_panel_applet_draw(GtkWidget* widget, cairo_t* cr)
 {
 	GtkStyleContext *context;
 	int border_width;
-#if !GTK_CHECK_VERSION (3, 18, 0)
-	int focus_width = 0;
-#endif
 	gdouble x, y, width, height;
 
 	GTK_WIDGET_CLASS (mate_panel_applet_parent_class)->draw(widget, cr);
@@ -1176,16 +1133,6 @@ static gboolean mate_panel_applet_draw(GtkWidget* widget, cairo_t* cr)
 	width = gtk_widget_get_allocated_width (widget);
 	height = gtk_widget_get_allocated_height (widget);
 
-#if !GTK_CHECK_VERSION (3, 18, 0)
-	/*
-	 * We are deliberately ignoring focus-padding here to
-	 * save valuable panel real estate.
-	 */
-	gtk_widget_style_get (widget,
-		"focus-line-width", &focus_width,
-		NULL);
-#endif
-
 	border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
 
 	x = 0;
@@ -1551,58 +1498,51 @@ mate_panel_applet_change_background(MatePanelApplet *applet,
 {
 	GtkStyleContext* context;
 	GdkWindow* window;
-#if GTK_CHECK_VERSION (3, 18, 0)
+
 	if (applet->priv->out_of_process)
 		window = gtk_widget_get_window (applet->priv->plug);
 	else
 		window = gtk_widget_get_window GTK_WIDGET((applet));
-#else
-		window = gtk_widget_get_window GTK_WIDGET((applet));
-#endif
-		gtk_widget_set_app_paintable(GTK_WIDGET(applet),TRUE);
-		if (applet->priv->out_of_process)
-			_mate_panel_applet_apply_css(GTK_WIDGET(applet->priv->plug),type);
-		switch (type) {
+
+	gtk_widget_set_app_paintable(GTK_WIDGET(applet),TRUE);
+
+	if (applet->priv->out_of_process)
+		_mate_panel_applet_apply_css(GTK_WIDGET(applet->priv->plug),type);
+
+	switch (type) {
 		case PANEL_NO_BACKGROUND:
 			if (applet->priv->out_of_process){
 				pattern = cairo_pattern_create_rgba (0,0,0,0);     /* Using NULL here breaks transparent */
 				gdk_window_set_background_pattern(window,pattern); /* backgrounds set by GTK theme */
-				}
+			}
 			break;
 		case PANEL_COLOR_BACKGROUND:
 			if (applet->priv->out_of_process){
 				gdk_window_set_background_rgba(window,color);
-#if GTK_CHECK_VERSION (3, 18, 0)
 				gtk_widget_queue_draw (applet->priv->plug); /*change the bg right away always */
-#else
-				gtk_widget_queue_draw (GTK_WIDGET(applet));
-#endif
-				}
+			}
 			break;
 		case PANEL_PIXMAP_BACKGROUND:
 			if (applet->priv->out_of_process){
 				gdk_window_set_background_pattern(window,pattern);
-#if GTK_CHECK_VERSION (3, 18, 0)
 				gtk_widget_queue_draw (applet->priv->plug); /*change the bg right away always */
-#else
-				gtk_widget_queue_draw (GTK_WIDGET(applet));
-#endif
-				}
+			}
 			break;
 		default:
 			g_assert_not_reached ();
 			break;
-		}
-		if (applet->priv->out_of_process){
+	}
+
+	if (applet->priv->out_of_process){
 		context = gtk_widget_get_style_context (GTK_WIDGET(applet->priv->plug));
 		if (applet->priv->orient == MATE_PANEL_APPLET_ORIENT_UP ||
 			applet->priv->orient == MATE_PANEL_APPLET_ORIENT_DOWN){
 			gtk_style_context_add_class(context,"horizontal");
-			}
+		}
 		else {
 			gtk_style_context_add_class(context,"vertical");
-			}
 		}
+	}
 }
 
 static void
@@ -1806,7 +1746,6 @@ static void _mate_panel_applet_prepare_css (GtkStyleContext *context)
 	GtkCssProvider  *provider;
 
 	provider = gtk_css_provider_new ();
-#if GTK_CHECK_VERSION (3, 18, 0)
 	gtk_css_provider_load_from_data (provider,
 					 "#PanelPlug {\n"
 					 " background-repeat: no-repeat;\n" /*disable in gtk theme features */
@@ -1817,14 +1756,7 @@ static void _mate_panel_applet_prepare_css (GtkStyleContext *context)
 					 " background-image: none;\n"
 					 "}",
 					 -1, NULL);
-#else
-gtk_css_provider_load_from_data (provider,
-					 ".mate-custom-panel-background{\n" /*prepare CSS for user set theme */
-					 " background-color: rgba (0, 0, 0, 0);\n"
-					 " background-image: none;\n"
-					 "}",
-					 -1, NULL);
-#endif
+
 	gtk_style_context_add_provider (context,
 					GTK_STYLE_PROVIDER (provider),
 					GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
@@ -1927,10 +1859,8 @@ mate_panel_applet_class_init (MatePanelAppletClass *klass)
 	widget_class->button_press_event = mate_panel_applet_button_press;
 	widget_class->button_release_event = mate_panel_applet_button_release;
 	widget_class->get_request_mode = mate_panel_applet_get_request_mode;
-#if !GTK_CHECK_VERSION (3, 18, 0)
 	widget_class->get_preferred_width = mate_panel_applet_get_preferred_width;
 	widget_class->get_preferred_height = mate_panel_applet_get_preferred_height;
-#endif
 	widget_class->draw = mate_panel_applet_draw;
 	widget_class->size_allocate = mate_panel_applet_size_allocate;
 	widget_class->focus = mate_panel_applet_focus;
@@ -2089,9 +2019,7 @@ mate_panel_applet_class_init (MatePanelAppletClass *klass)
 	add_tab_bindings (binding_set, GDK_CONTROL_MASK, GTK_DIR_TAB_FORWARD);
 	add_tab_bindings (binding_set, GDK_CONTROL_MASK | GDK_SHIFT_MASK, GTK_DIR_TAB_BACKWARD);
 
-#if GTK_CHECK_VERSION (3, 20, 0)
 	gtk_widget_class_set_css_name (widget_class, "PanelApplet");
-#endif
 }
 
 GtkWidget* mate_panel_applet_new(void)
@@ -2410,31 +2338,11 @@ mate_panel_applet_factory_setup_in_process (const gchar               *factory_i
  * Deprecated: 3.20: Do not use this API. Since 3.20 this function does nothing.
  **/
 
-#if GTK_CHECK_VERSION (3, 18, 0)
 void
 mate_panel_applet_set_background_widget (MatePanelApplet *applet,
 				    GtkWidget   *widget)
 {
 }
-#else
-void
-mate_panel_applet_set_background_widget (MatePanelApplet *applet,
-				    GtkWidget   *widget)
-{
-	applet->priv->background_widget = widget;
-
-	if (widget && gtk_widget_get_realized (widget)) {
-		MatePanelAppletBackgroundType  type;
-		GdkRGBA                    color;
-		cairo_pattern_t           *pattern;
-		type = mate_panel_applet_get_background (applet, &color, &pattern);
-		_mate_panel_applet_apply_css(widget,type);
-
-		if (type == PANEL_PIXMAP_BACKGROUND)
-			cairo_pattern_destroy (pattern);
-	}
-}
-#endif
 
 guint32
 mate_panel_applet_get_xid (MatePanelApplet *applet,
