@@ -1129,15 +1129,28 @@ panel_run_dialog_update_content (PanelRunDialog *dialog,
 		gtk_window_set_resizable (GTK_WINDOW (dialog->run_dialog), FALSE);
                 gtk_widget_grab_focus (dialog->combobox);
 
-	} else if (show_list) {
-		gtk_window_resize (GTK_WINDOW (dialog->run_dialog), 100, 300);
-		gtk_window_set_resizable (GTK_WINDOW (dialog->run_dialog), TRUE);
-		gtk_widget_grab_focus (dialog->program_list);
+	} else {
 
-        } else if (!show_list) {
-		gtk_window_set_resizable (GTK_WINDOW (dialog->run_dialog), FALSE);
-                gtk_widget_grab_focus (dialog->combobox);
+        /* if the list is closed and the user wants to see it */
+        if (show_list && !gtk_expander_get_expanded (GTK_EXPANDER (dialog->list_expander))) {
+
+            /* open the expander, this shows the list */
+            gtk_expander_set_expanded (GTK_EXPANDER (dialog->list_expander), TRUE);
+
+            gtk_window_resize (GTK_WINDOW (dialog->run_dialog), 100, 300);
+            gtk_window_set_resizable (GTK_WINDOW (dialog->run_dialog), TRUE);
+            gtk_widget_grab_focus (dialog->program_list);
+
+        /* if the list is open and the user wants to close it */
+        } else if (!show_list && gtk_expander_get_expanded (GTK_EXPANDER (dialog->list_expander))) {
+
+            /* close the expander, this hides the list */
+            gtk_expander_set_expanded (GTK_EXPANDER (dialog->list_expander), FALSE);
+
+            gtk_window_set_resizable (GTK_WINDOW (dialog->run_dialog), FALSE);
+            gtk_widget_grab_focus (dialog->combobox);
         }
+    }
 }
 
 static void
@@ -1207,8 +1220,8 @@ file_button_clicked (GtkButton      *button,
 	chooser = gtk_file_chooser_dialog_new (_("Choose a file to append to the command..."),
 					       GTK_WINDOW (dialog->run_dialog),
 					       GTK_FILE_CHOOSER_ACTION_OPEN,
-					       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					       GTK_STOCK_OK, GTK_RESPONSE_OK,
+					       "gtk-cancel", GTK_RESPONSE_CANCEL,
+					       "gtk-ok", GTK_RESPONSE_OK,
 					       NULL);
 
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (chooser),
@@ -1450,10 +1463,14 @@ entry_event (GtkEditable    *entry,
 	if (event->type != GDK_KEY_PRESS)
 		return FALSE;
 
-	/* if user typed something we're not using the list anymore */
+	/* if user typed something we're not using the list anymore
+	   (but only if it is enabled anyway)
+	*/
 	dialog->use_program_list = FALSE;
-	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (dialog->program_list));
-	gtk_tree_selection_unselect_all (selection);
+	if (panel_profile_get_enable_program_list ()) {
+		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (dialog->program_list));
+		gtk_tree_selection_unselect_all (selection);
+	}
 
 	if (!panel_profile_get_enable_autocompletion ())
 		return FALSE;
@@ -1691,6 +1708,7 @@ panel_run_dialog_setup_entry (PanelRunDialog *dialog,
 	GdkScreen             *screen;
 	int                    width_request;
 	GtkWidget             *entry;
+	gint                   scale;
 
 	dialog->combobox = PANEL_GTK_BUILDER_GET (gui, "comboboxentry");
 
@@ -1703,9 +1721,10 @@ panel_run_dialog_setup_entry (PanelRunDialog *dialog,
 		(GTK_COMBO_BOX (dialog->combobox), 0);
 
 	screen = gtk_window_get_screen (GTK_WINDOW (dialog->run_dialog));
+	scale = gtk_widget_get_scale_factor (GTK_WIDGET (dialog->run_dialog));
 
         /* 1/4 the width of the first monitor should be a good value */
-	width_request = panel_multiscreen_width (screen, 0) / 4;
+	width_request = panel_multiscreen_width (screen, 0) / (4 * scale);
 	g_object_set (G_OBJECT (dialog->combobox),
 		      "width_request", width_request,
 		      NULL);
